@@ -214,8 +214,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         simple context option, removes item from list
         """
         url = self.ui_fs_serverlist.currentItem().text()
-        msg = QtWidgets.QMessageBox()
-        selected = msg.information(self, u"Remove FS Dir", url, QMessageBox.Ok | QMessageBox.Cancel)
+        selected = QMessageBox.information(self, u"Remove FS Dir", url, QMessageBox.Ok | QMessageBox.Cancel)
         if selected == QMessageBox.Ok:
             self.ui_fs_serverlist.clear()
             for item in self.settings.value("fs_urls"):
@@ -228,10 +227,9 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         loads the selected fs to the file list ui
         """
         self.directory_history = []
+        self.wparm = None
         if self.fs:
             self.fs.close()
-        if self.wparm is not None:
-            self.wparm = None
         try:
             self.fs = fs.open_fs(self.active_url)
         except IOError:
@@ -278,6 +276,8 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         """
         Fills the filenames based on file_type into a FileList, also directories
         """
+        if not self.show_save_action:
+            self.ui_SelectedName.setText(None)
         QtWidgets.QApplication.setOverrideCursor(QtCore.Qt.WaitCursor)
         self.selected_dir = self.ui_DirList.currentText()
         self.ui_FileList.clearContents()
@@ -300,12 +300,12 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             try:
                 names = self.fs.listdir(_sel_dir)
                 # cleanup not valid names
-                # ToDo improve for other cases, e.g. fs.errors.PermissionDenied
+                # ToDo improve make those problematic files not clickable
                 for item in names:
                     _item = fs.path.combine(_sel_dir, item)
                     try:
                         self.fs.isdir(_item)
-                    except TypeError:
+                    except (TypeError, fs.errors.PermissionDenied):
                         names.remove(item)
                         logging.error("item name %s removed from list" % item)
                 for item in sorted(names):
@@ -390,6 +390,8 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
                 if "folder" in self.wparm.img:
                     self.directory_history.append(list(self.wparm.value.keys())[0])
                     self.browse_folder(subdir=list(self.wparm.value.keys())[0])
+                    if not self.show_save_action:
+                        self.ui_SelectedName.setText(None)
                     self.selection_name()
                 if "text" in self.wparm.img:
                     self.ui_SelectedName.setText(self.wparm.text)
@@ -414,19 +416,25 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         """
         Action for filename changes, line edit text input
         """
+        if not self.show_save_action and not self.show_dirs_only:
+            self.ui_Action.setEnabled(False)
         self.filename = self.ui_SelectedName.text()
-        dirname = u'./'
+        dirname = fs.path.forcedir(u'.')
         if self.wparm is not None:
-            if self.wparm.value == u'./{}'.format(self.wparm.text):
-                dirname = fs.path.dirname(u'./{}'.format(self.wparm.text))
+            _dirname = fs.path.forcedir(u'.')
+            if self.wparm.value == u'{}{}'.format(_dirname, self.wparm.text):
+                dirname = fs.path.dirname(u'{}{}'.format(_dirname, self.wparm.text))
             else:
-                dirname = fs.path.dirname(list(self.wparm.value)[0])
+                dirname = self.selected_dir
         if not self.show_dirs_only:
             _filename = fs.path.combine(dirname, self.filename)
             _file_names = [list(name)[0] for name in self.file_list_items]
-
-            if self.fs.exists(_filename) and _filename in _file_names:
+            if dirname == fs.path.forcedir(u'.'):
+                _file_names = [fs.path.combine(dirname, list(name)[0]) for name in self.file_list_items]
+            if _filename in _file_names:
                 self.ui_Action.setEnabled(True)
+                index = _file_names.index(_filename) + len(self.dir_list_items)
+                self.ui_FileList.selectRow(index)
             else:
                 if not self.show_save_action:
                     self.ui_Action.setEnabled(False)
@@ -494,6 +502,9 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         Action for top dir in history_list
         """
         self.browse_folder(self.active_url)
+        if not self.show_save_action:
+            self.ui_SelectedName.setText(None)
+        self.selection_name()
 
     def history_next(self):
         """
@@ -502,6 +513,9 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         index = list(reversed(self.directory_history)).index(self.selected_dir) - 1
         if index >= 0:
             self.ui_DirList.setCurrentIndex(index)
+        if not self.show_save_action:
+            self.ui_SelectedName.setText(None)
+        self.selection_name()
 
     def history_previous(self):
         """
@@ -510,48 +524,56 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         index = list(reversed(self.directory_history)).index(self.selected_dir) + 1
         if index < len(self.directory_history):
             self.ui_DirList.setCurrentIndex(index)
+        if not self.show_save_action:
+            self.ui_SelectedName.setText(None)
+        self.selection_name()
 
     def action(self):
         """
         Action on Open / Save button
         """
-        if self.show_save_action:
+        self.filename = self.ui_SelectedName.text()
+        if self.filename == u"":
+            return
+
+        if self.filename is not None:
+            dirname = fs.path.forcedir(u'.')
+            if self.wparm is not None:
+                dirname = self.selected_dir
+            if dirname.startswith(self.active_url):
+                filename = u"{}{}".format(fs.path.forcedir(self.active_url), self.filename)
+            else:
+                # We can't use fs.path.join and also not fs.path.abspath because of protocol url
+                filename = u"{}{}{}".format(fs.path.forcedir(self.active_url),
+                                            fs.path.forcedir(dirname), self.filename)
+            filename = filename.replace(fs.path.forcedir(u'.'), u'')
+        if self.show_save_action and not self.show_dirs_only:
             self.save_settings()
             self.filename = self.ui_SelectedName.text()
             if self.filename == u"":
                 return
-            dirname = u'.{}'.format(u"/")
-            if self.wparm is not None:
-                if self.wparm.value == u'.{}{}'.format(u"/", self.wparm.text):
-                    dirname = fs.path.dirname(u'.{}{}'.format(u"/", self.wparm.text))
-                else:
-                    dirname = fs.path.dirname(self.wparm.value)
-            filename = fs.path.join(dirname, self.filename)
-            if self.fs.isdir(filename):
+
+            if fs_url_exists(filename):
                 sel = QtWidgets.QMessageBox.warning(
                     self, u"Warning",
                     u"You can't create a file with this name: {0}".format(self.filename),
                     QtWidgets.QMessageBox.No)
-            elif self.fs.exists(filename):
+            elif fs_file_exists(fs.path.split(filename)):
                 sel = QtWidgets.QMessageBox.question(
                     self, u"Replace Filename",
                     u"This will replace the filename: {0}. Continue?".format(self.filename),
                     QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
                 if sel == QtWidgets.QMessageBox.Yes:
+                    self.filename = filename
                     self.close()
                 else:
                     pass
             else:
+                self.filename = filename
                 self.close()
         else:
-            try:
-                self.filename = self.ui_SelectedName.text()
-                if self.filename == u"":
-                    self.filename = None
-            except AttributeError:
-                pass
-            else:
-                self.close()
+            self.filename = filename
+            self.close()
 
     def save_settings(self):
         items = []
@@ -590,14 +612,7 @@ def fs_filepicker(parent=None, fs_url=u'~/', file_pattern=u'All Files (*)', titl
     filename = None
     selected_file_pattern = None
     if fp.filename is not None:
-        dirname = u'.{}'.format(u"/")
-        if fp.wparm is not None:
-            dirname = fp.selected_dir
-        if dirname.startswith(fp.active_url):
-            filename = u"{}{}".format(fs.path.forcedir(active_url), fp.filename)
-        else:
-            # We can't use fs.path.join and also not fs.path.abspath because of protocol url
-            filename = u"{}{}{}".format(fs.path.forcedir(active_url), fs.path.forcedir(dirname), fp.filename)
+        filename = fp.filename.replace(fp.active_url, active_url)
         try:
             selected_file_pattern = fp.selected_file_pattern[0]
         except TypeError:
